from imports import *
file_path="/home/flerb/Documents/pythonTools/modules/src/modules/abstract_paths/src/abstract_paths/finderTab"
result = findContent(file_path,strings='gg',add=True)
input(result)
